body{margin:0;font-family:-apple-system,BlinkMacSystemFont,"Segoe UI","Roboto","Oxygen","Ubuntu","Cantarell","Fira Sans","Droid Sans","Helvetica Neue",sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}code{font-family:source-code-pro,Menlo,Monaco,Consolas,"Courier New",monospace}.App{text-align:center;min-height:100vh}.appContent{position:relative}body{min-height:100%;background:#f5f5f5}div[tabindex="-1"]:focus{outline:0}.scrollView::-webkit-scrollbar{display:none}.scrollView{overflow-y:scroll;-ms-overflow-style:none}.faded{position:relative}.faded:after{content:"";position:absolute;z-index:1;bottom:0;left:0;pointer-events:none;background-image:linear-gradient(180deg,hsla(0,0%,100%,0),#fff 90%);width:100%;height:4em}.pulse{-webkit-animation:pulse 1s infinite;animation:pulse 1s infinite;-webkit-animation-timing-function:linear;animation-timing-function:linear}@-webkit-keyframes pulse{0%{transform:scale(1)}50%{transform:scale(1.1)}to{transform:scale(1)}}@keyframes pulse{0%{transform:scale(1)}50%{transform:scale(1.1)}to{transform:scale(1)}}.removePlot{transition:opacity .5s}.removePlot:hover{opacity:.4}.actionButton{cursor:pointer}.plotInitializer{transition:all .5s ease}.plotInitializer.hidden{width:0;height:0;overflow:hidden}.sectionHeader{font-size:1.2em;font-weight:700;text-align:left;padding-bottom:7pt;margin-bottom:20pt;border-bottom:1pt solid #ccc}@font-face{font-family:"Material Icons";font-style:normal;font-weight:400;src:url(../../static/media/MaterialIcons-Regular.e79bfd88.eot);src:local("Material Icons"),local("MaterialIcons-Regular"),url(../../static/media/MaterialIcons-Regular.570eb838.woff2) format("woff2"),url(../../static/media/MaterialIcons-Regular.012cf6a1.woff) format("woff"),url(../../static/media/MaterialIcons-Regular.a37b0c01.ttf) format("truetype")}.material-icons{font-family:"Material Icons";font-weight:400;font-style:normal;font-size:24px;display:inline-block;line-height:1;text-transform:none;letter-spacing:normal;word-wrap:normal;white-space:nowrap;direction:ltr;-webkit-font-smoothing:antialiased;text-rendering:optimizeLegibility;-moz-osx-font-smoothing:grayscale;font-feature-settings:"liga"}.structGroupAction{background-color:#ccc;padding-top:5pt;padding-left:20pt;padding-right:20pt;margin-top:5pt;margin-right:5pt;border-top-left-radius:2pt;border-top-right-radius:2pt;cursor:pointer;transition:all .3s}.structGroupAction:hover{margin-top:0;padding-left:25pt;padding-right:25pt}.structurePicker{border-radius:5px;border-color:#000;margin:10;display:flex;flex-wrap:wrap;overflow:hidden;justify-content:space-between;background:#fff}.structureCell{cursor:pointer;padding:20px 0;border-radius:3px}.structureCell.selected{background:#bef}.structureCell:hover:not(.selected){background:#9cf}.plotTab{transition:all .5s;cursor:pointer;display:flex;align-items:center;justify-content:center;height:40px;padding:0 20px;border-radius:20px;margin:0 20px}.plotTab:hover{background:hsla(0,0%,100%,.4)}.plotTab.active{background:#fff;color:#000;cursor:default;padding:0 10px 0 15px}[contenteditable=true]{cursor:text}[contenteditable=true].singleLine{white-space:nowrap;overflow:hidden}[contenteditable=true].singleLine br{display:none}[contenteditable=true].singleLine *{display:inline;white-space:nowrap}.removeTabBut{margin-left:10px;display:flex;justify-content:center;align-items:center;color:#ccc;height:auto;cursor:pointer;transition:all .5s ease}.removeTabBut:hover{transform:scale(1.1);color:red}.newTabIcon{transition:all .5s;cursor:pointer}.newTabIcon:hover{color:rgba(77,150,35,.644)!important;transform:scale(1.1)}.plotcard>.card-content{padding:0}.collapsible-header{transition:background 1s;background:#fff}.collapsible-header:hover{background:#9cf}.collapsible-header.active{background:#7af;font-weight:700}.collapsible-body{background:#fff}.fill{height:100%;width:100%}.switch{padding-bottom:10px}.queryCard{transition:all 1s}.querySelect{flex:1 1}.structTag{padding:10px;margin-top:5px;margin-bottom:5px;background-color:#ccc;border-radius:30px;cursor:pointer}.structTag:hover{background-color:silver}.structTag.active{background-color:#999}.plotableTag{padding:10px;margin-top:5px;margin-bottom:5px;background-color:#e0ffff;border-radius:30px;cursor:pointer}.plotableTag:hover{background-color:#add8e6}.plotableTag.active{background-color:#0ff}.structPickerToggle{padding:5px;margin-left:1px;margin-right:1px;background-color:#fff;color:"black";border-radius:5px;cursor:pointer;transition:all .2s}.structPickerToggle:hover{background-color:silver}.structPickerToggle.active{background-color:#999;color:#fff;font-weight:700}.loadingTracker{display:flex;flex-direction:row;justify-content:flex-end;margin:10px 20px;transition:all .5s}.loadingTracker.empty{margin:0}.loadingChip{display:flex;flex-direction:row;padding:10px;background-color:#ffebcd;border-radius:5px;margin-right:20px;margin-left:20px}.arrayContainer{border:6px solid #000;border-top:none;border-bottom:none;border-radius:5px}
/*# sourceMappingURL=main.7265e407.chunk.css.map */